@@ -27,7 +27,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
@@ -41,7 +41,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
@@ -55,7 +55,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
@@ -69,7 +69,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
@@ -99,7 +99,7 @@
 "nor_county_position_geolabels_b2017_default_dt"
 
 ## sf format ----
-#' Maps of Norwegian municipalities in sf format
+#' Maps of Norwegian counties in sf format
 #'
 #' This data is licensed under Creative Commons BY 4.0 (CC BY 4.0).
 #'
@@ -150,7 +150,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + annotate(
 #'   "text",
@@ -171,7 +171,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + annotate(
 #'   "text",
@@ -191,7 +191,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + annotate(
 #'   "text",
@@ -211,7 +211,7 @@
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + annotate(
 #'   "text",
@@ -269,12 +269,43 @@
 #' # 2024 borders
 #' library(ggplot2)
 #' q <- ggplot(mapping = aes(x = long, y = lat))
+#' q <- q + csmaps::annotate_oslo_nor_map_bxxxx_split_dt()
 #' q <- q + geom_polygon(
 #'   data = csmaps::nor_county_map_b2024_split_dt,
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
+#' )
+#' q <- q + theme_void()
+#' q <- q + coord_quickmap()
+#' q
+#'
+#' # 2024 borders
+#' library(ggplot2)
+#' q <- ggplot(mapping = aes(x = long, y = lat))
+#' q <- q + csmaps::annotate_oslo_nor_map_bxxxx_split_dt()
+#' q <- q + geom_polygon(
+#'   data = csmaps::nor_county_map_b2024_split_dt,
+#'   mapping = aes(group = group),
+#'   color = "black",
+#'   fill = "white",
+#'   linewidth = 0.4
+#' )
+#' q <- q + ggrepel::geom_label_repel(
+#'   data = csmaps::nor_county_position_geolabels_b2024_split_dt[repel==TRUE],
+#'   mapping = aes(x = long, y = lat, label = location_code),
+#'   size = 3,
+#'   label.size = 0.1,
+#'   label.r = grid::unit(0, "lines"),
+#'   min.segment.length = 0
+#' )
+#' q <- q + geom_label(
+#'   data = csmaps::nor_county_position_geolabels_b2024_split_dt[repel==FALSE],
+#'   mapping = aes(x = long, y = lat, label = location_code),
+#'   size = 3,
+#'   label.size = 0.1,
+#'   label.r = grid::unit(0, "lines")
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
@@ -283,20 +314,56 @@
 #' # 2020 borders
 #' library(ggplot2)
 #' q <- ggplot(mapping = aes(x = long, y = lat))
+#' q <- q + csmaps::annotate_oslo_nor_map_bxxxx_split_dt()
 #' q <- q + geom_polygon(
 #'   data = csmaps::nor_county_map_b2020_split_dt,
 #'   mapping = aes(group = group),
 #'   color = "black",
 #'   fill = "white",
-#'   linewidth = 0.2
+#'   linewidth = 0.4
 #' )
 #' q <- q + theme_void()
 #' q <- q + coord_quickmap()
 #' q
-#' @name nor_county_map_bxxxx_split_dt
-"nor_county_map_b2020_split_dt"
-
 #' @name nor_county_map_bxxxx_split_dt
 "nor_county_map_b2024_split_dt"
 
+#' @name nor_county_map_bxxxx_split_dt
+"nor_county_map_b2020_split_dt"
 
+#' @rdname nor_county_map_bxxxx_split_dt
+"nor_county_position_geolabels_b2024_split_dt"
+
+#' @rdname nor_county_map_bxxxx_split_dt
+"nor_county_position_geolabels_b2020_split_dt"
+
+#' @rdname nor_county_map_bxxxx_split_dt
+#' @export
+annotate_oslo_nor_map_bxxxx_split_dt <- function(){
+  list(
+    # ggplot2::annotate(
+    #   "rect",
+    #   xmin = 0.5,
+    #   xmax = 3.9,
+    #   ymin = 58.9,
+    #   ymax = 61.4,
+    #   alpha = .2,
+    #   fill = "grey"
+    # ),
+    ggplot2::annotate(
+      "rect",
+      xmin = 0.5,
+      xmax = 3.9,
+      ymin = 58.9,
+      ymax = 61.4,
+      fill = "white",
+      color = "black"
+    ),
+    ggplot2::annotate(
+      "text",
+      x = 2.2,
+      y = 59.15,
+      label = "Oslo"
+    )
+  )
+}
